@@ -23,7 +23,7 @@
 #'   are set to ep_bc.
 #' @param num A numeric scalar. Number of values at which to evaluate logf.
 #' @param xdiv A numeric scalar.  Only values of phi at which the density f is
-#'   greater than the (maximum of f)/xdiv are used.
+#'   greater than the (maximum of f) / \code{xdiv} are used.
 #' @param probs A numeric scalar. Probabilities at which to estimate the
 #'   quantiles of that will be used as data to find lambda.
 #' @param lambda_range A numeric vector of length 2.  Range of lambda over
@@ -71,10 +71,9 @@
 #'
 #' @references Box, G. and Cox, D. R. (1964) An Analysis of Transformations.
 #'  Journal of the Royal Statistical Society. Series B (Methodological), 26(2),
-#'  211-252, \url{https://www.jstor.org/stable/2984418}.
+#'  211-252.
 #' @references Andrews, D. F. and Gnanadesikan, R. and Warner, J. L. (1971)
-#'  Transformations of Multivariate Data, Biometrics, 27(4),
-#'  \url{https://dx.doi.org/10.2307/2528821}.
+#'  Transformations of Multivariate Data, Biometrics, 27(4).
 #' @references Eddelbuettel, D. and Francois, R. (2011). Rcpp: Seamless
 #'  R and C++ Integration. \emph{Journal of Statistical Software},
 #'  \strong{40}(8), 1-18.
@@ -244,7 +243,7 @@ find_lambda_one_d_rcpp <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
   areas <- wbar * xdiff
   w <- areas / sum(areas)
   # Estimate the 100*probs% quantiles of the density
-  qs <- spatstat::quantile.ewcdf(spatstat::ewcdf(xmid, w), probs = probs)
+  qs <- stats::quantile(wecdf(xmid, w), probs = probs)
   qs <- matrix(qs, ncol = 1)
   # Use the quantiles qs as a sample of data to estimate lambda
   # Set to 1 all the input weights associated with the quantiles
@@ -325,10 +324,9 @@ find_lambda_one_d_rcpp <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
 #'  \item{user_args}{as detailed above (only if \code{user_args} is supplied)}
 #' @references Box, G. and Cox, D. R. (1964) An Analysis of Transformations.
 #'  Journal of the Royal Statistical Society. Series B (Methodological), 26(2),
-#'  211-252, \url{https://www.jstor.org/stable/2984418}.
+#'  211-252.
 #' @references Andrews, D. F. and Gnanadesikan, R. and Warner, J. L. (1971)
-#'  Transformations of Multivariate Data, Biometrics, 27(4),
-#'  \url{https://dx.doi.org/10.2307/2528821}.
+#'  Transformations of Multivariate Data, Biometrics, 27(4).
 #' @references Eddelbuettel, D. and Francois, R. (2011). Rcpp: Seamless
 #'  R and C++ Integration. \emph{Journal of Statistical Software},
 #'  \strong{40}(8), 1-18.
