@@ -15,7 +15,7 @@
 #'     \item{sum_gp}{A numeric scalar. The sum of the non-missing sample
 #'     values.}
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Sample data from a GP(sigma, xi) distribution
 #' gpd_data <- rgpd(m = 100, xi = 0, sigma = 1)
 #' # Calculate summary statistics for use in the log-likelihood
@@ -58,7 +58,7 @@ gpd_sum_stats <- function(gpd_data) {
 #' Bayesian extreme value analyses using reference priors. Statistica Sinica,
 #' 26(2), 721-743, \url{http://dx.doi.org/10.5705/ss.2014.034}.
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Sample data from a GP(sigma, xi) distribution
 #' gpd_data <- rgpd(m = 100, xi = 0, sigma = 1)
 #' # Calculate summary statistics for use in the log-likelihood
@@ -84,7 +84,7 @@ gpd_logpost <- function(pars, ss) {
 #' @param xi A numeric scalar.  The generalized Pareto shape parameter.
 #' @return A numeric vector.  A generalized Pareto sample of size \code{m}.
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Sample data from a GP(sigma, xi) distribution
 #' gpd_data <- rgpd(m = 100, xi = 0, sigma = 1)
 #' }
@@ -175,7 +175,7 @@ rgpd <- function (m = 1, sigma = 1, xi = 0) {
 #' @seealso \code{\link{find_lambda}} to produce (somewhat) automatically
 #'   a list for the argument \code{lambda} of \code{ru}.
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Sample data from a GP(sigma, xi) distribution
 #' gpd_data <- rgpd(m = 100, xi = 0, sigma = 1)
 #' # Calculate summary statistics for use in the log-likelihood
@@ -266,139 +266,3 @@ gpd_init <- function(gpd_data, m, xm, sum_gp = NULL, xi_eq_zero = FALSE,
   init_phi <- theta_to_phi(init)
   return(list(init = init, se = se, init_phi = init_phi, se_phi = se_phi))
 }
-
-# =========================== log_gpd_mdi_prior ===========================
-
-log_gpd_mdi_prior <- function(pars) {
-  # Generalized Pareto MDI prior log-density
-  #
-  # Calculates the log-density of a Maximal Data Information (MDI) prior
-  # for generalized Pareto parameters.  The prior density is truncated,
-  # (to xi >= -1), to produce a posterior density that is proper.
-  #
-  # Args:
-  #   pars : A numeric vector containing the values of the generalized Pareto
-  #          parameters sigma and xi.
-  #
-  # Returns:
-  #   A numeric scalar. The value of the prior log-density.
-  #
-  if (pars[1] <= 0 | pars[2] < -1) {
-    return(-Inf)
-  }
-  return(-log(pars[1]) - pars[2] - 1)
-}
-
-# =========================== gpd_loglik ===========================
-
-gpd_loglik <- function(pars, gpd_data, m, xm, sum_gp) {
-  # Generalized Pareto log-likelihood
-  #
-  # Calculates the log-likelihood for a random sample from a Generalized Pareto.
-  #
-  # Args:
-  #   pars     : A numeric vector containing the values of the generalized
-  #              Pareto parameters sigma and xi.
-  #   gpd_data : A numeric vector containing positive sample values.
-  #   m        : A numeric scalar.  The sample size: the length of gpd_data.
-  #   xm       : A numeric scalar. The sample maximum.
-  #   sum_gp   : The sum of the sample values.
-  #
-  # Returns:
-  #   A numeric scalar. The value of the log-likelihood.
-  #
-  if (pars[1] <= 0 | pars[2] <= -pars[1] / xm)
-    return(-Inf)
-  sdat <- gpd_data / pars[1]
-  zz <- 1 + pars[2] * sdat
-  if (abs(pars[2]) > 1e-6) {
-    val <- -m * log(pars[1]) - (1 + 1 / pars[2]) * sum(log(zz))
-  } else {
-    i <- 1:4
-    g_fun <- function(x) {
-      t1 <- x ^ i
-      t2 <- (i * x - i - 1)
-      sum((-1) ^ i * t1 * t2 * pars[2] ^ i / i / (i + 1))
-    }
-    val <- -m * log(pars[1]) - sum_gp / pars[1] - sum(sapply(sdat, g_fun))
-  }
-  return(val)
-}
-
-# =========================== gpd_mle ===========================
-
-gpd_mle <- function(gpd_data) {
-  # Maximum likelihood estimation for the generalized Pareto distribution
-  #
-  # Performs maximum likelihood estimation for the generalized Pareto
-  # distribution.  Uses the function \code{gpdmle} associated with
-  # Grimshaw (1993), which returns MLEs of sigma and k = - \xi.
-  #
-  # Grimshaw, S. D. (1993) Computing Maximum Likelihood Estimates
-  #   for the Generalized Pareto Distribution.  Technometrics, 35(2), 185-191.
-  #   and Computing (1991) 1, 129-133. http://dx.doi.org/10.1007/BF01889987.
-  #
-  # Args:
-  #   gpd_data : A numeric vector containing positive values, assumed to be a
-  #             random sample from a generalized Pareto distribution.
-  #
-  # Returns:
-  #   A list with components
-  #     mle  : A numeric vector.  MLEs of GP parameters sigma and xi.
-  #     nllh : A numeric scalar.  The negated log-likelihood at the MLE.
-  #
-  # Call Grimshaw (1993) function, note: k is -xi, a is sigma
-#  pjn <- grimshaw_gpdmle(gpd_data)
-  temp <- list()
-  # Use revdbayes function if revdbayes is available, otherwise use fallback
-  if (requireNamespace("revdbayes", quietly = TRUE)) {
-    pjn <- revdbayes:::grimshaw_gp_mle(gpd_data)
-    temp$mle <- c(pjn$a, -pjn$k)  # mle for (sigma,xi)
-  } else {
-    temp <- fallback_gp_mle(init = c(mean(gpd_data), 0), gpd_data = gpd_data,
-                            m = length(gpd_data), xm = max(gpd_data),
-                            sum_gp = sum(gpd_data))
-  }
-  sc <- rep(temp$mle[1], length(gpd_data))
-  xi <- temp$mle[2]
-  temp$nllh <- sum(log(sc)) + sum(log(1 + xi * gpd_data / sc) * (1 / xi + 1))
-  return(temp)
-}
-
-# =========================== fallback_gp_mle ===========================
-
-fallback_gp_mle <- function(init, ...){
-  x <- stats::optim(init, gpd_loglik, ..., control = list(fnscale = -1),
-                    hessian = FALSE)
-  temp <- list()
-  temp$mle <- x$par
-  temp$nllh <- -x$value
-  return(temp)
-}
-
-# =========================== gpd_obs_info ===========================
-
-gpd_obs_info <- function(gpd_pars, y) {
-  # Observed information for the generalized Pareto distribution
-  #
-  # Calculates the observed information matrix for a random sample \code{y}
-  # from the generalized Pareto distribution, i.e. the negated Hessian matrix of
-  # the generalized Pareto log-likelihood, evaluated at \code{gpd_pars}.
-  #
-  # Args:
-  #   gpd_pars : A numeric vector. Parameters sigma and xi of the
-  #   generalized Pareto distribution.
-  #   y       : A numeric vector. A sample of positive data values.
-  #
-  # Returns:
-  #   A 2 by 2 numeric matrix.  The observed information matrix.
-  #
-  s <- gpd_pars[1]
-  x <- gpd_pars[2]
-  i <- matrix(NA, 2, 2)
-  i[1,1] <- -sum((1 - (1 + x) * y * (2 * s + x * y) / (s + x * y) ^ 2) / s ^ 2)
-  i[1,2] <- i[2,1] <- -sum(y * (1 - y / s) / (1 + x * y / s) ^ 2 / s ^ 2)
-  i[2,2] <- sum(2 * log(1 + x * y / s) / x ^ 3 - 2 * y / (s + x * y) / x ^ 2 -
-                  (1 + 1 / x) * y ^ 2 / (s + x * y) ^ 2)
-  return(i)
-}
